@@ -1,6 +1,6 @@
   /*
 
-  knat v 2.1.2
+  knat v 2.1.3
 
   Copyright (C) 2001 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -66,6 +66,7 @@ knetfilter::knetfilter( QWidget *, const char *name )
     log1="-v";
     log2="-v";
     log3="-v";
+    tcpmssChoice="FORWARD";
 	
     setupMenuBar();
     setupToolBar();
@@ -95,6 +96,7 @@ knetfilter::knetfilter( QWidget *, const char *name )
     dumpList = NULL;
     mapList = NULL;
     masqWin = NULL;
+    tcpmssList = NULL;
 };
 
 
@@ -183,6 +185,9 @@ void knetfilter::setupMenuBar() {
                 		this, SLOT(stopMangle()), CTRL+Key_M); 
 
   options->insertSeparator();
+  options->insertItem(i18n("TcpMSS set up"),
+		                this, SLOT(tcpmssRules()));
+  options->insertSeparator();
   options->insertItem(i18n("List Rules, Masquerading & Mangle entries"),
   				this, SLOT(iptablesRules()));
   options->insertSeparator();
